@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2008 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,64 +38,44 @@
 #include "avahi-publisher-main.h"
 #include "avahi-publisher.h"
 
-#include <iostream>
-
-class Service: public Ekiga::Service
+struct AVAHIPUBSpark: public Ekiga::Spark
 {
-public:
+  AVAHIPUBSpark (): result(false)
+  {}
 
-  Service (Ekiga::PresenceCore& core_,
-	   Avahi::PresencePublisher* publisher_):
-    core(core_), publisher(publisher_)
+  bool try_initialize_more (Ekiga::ServiceCore& core,
+			    int* /*argc*/,
+			    char** /*argv*/[])
   {
-    core.add_presence_publisher (*publisher);
+    boost::shared_ptr<Ekiga::PresenceCore> presence_core = core.get<Ekiga::PresenceCore> ("presence-core");
+    boost::shared_ptr<Ekiga::CallCore> call_core = core.get<Ekiga::CallCore> ("call-core");
+    boost::shared_ptr<Ekiga::PersonalDetails> details = core.get<Ekiga::PersonalDetails> ("personal-details");
+
+    if (presence_core && call_core && details) {
+
+      boost::shared_ptr<Avahi::PresencePublisher> publisher (new Avahi::PresencePublisher (core, *details, *call_core));
+      if (core.add (publisher)) {
+
+	presence_core->add_presence_publisher (publisher);
+	result = true;
+      }
+    }
+
+    return result;
   }
 
-  ~Service ()
-  {
-    core.remove_presence_publisher (*publisher);
-    delete publisher;
-  }
+  Ekiga::Spark::state get_state () const
+  { return result?FULL:BLANK; }
 
   const std::string get_name () const
-  { return "avahi-presence-publisher"; }
+  { return "AVAHIPUB"; }
 
-  const std::string get_description () const
-  { return "\tObject bringing in Avahi presence publishing"; }
-
-private:
-  Ekiga::PresenceCore& core;
-  Avahi::PresencePublisher* publisher;
+  bool result;
 };
 
-bool
-avahi_publisher_init (Ekiga::ServiceCore &core,
-                      int* /*argc*/,
-                      char* */*argv*/[])
+void
+avahi_publisher_init (Ekiga::KickStart& kickstart)
 {
-  bool result = false;
-  Ekiga::PresenceCore* presence_core = NULL;
-  Ekiga::CallCore* call_core = NULL;
-  Ekiga::PersonalDetails* details = NULL;
-
-  presence_core
-    = dynamic_cast<Ekiga::PresenceCore*>(core.get ("presence-core"));
-  call_core
-    = dynamic_cast<Ekiga::CallCore*>(core.get ("call-core"));
-  details
-    = dynamic_cast<Ekiga::PersonalDetails*>(core.get ("personal-details"));
-
-  if (presence_core != NULL
-      && call_core != NULL
-      && details != NULL) {
-
-    Avahi::PresencePublisher* publisher = NULL;
-    Service* service = NULL;
-    publisher = new Avahi::PresencePublisher (core, *details, *call_core);
-    service = new Service (*presence_core, publisher);
-    core.add (*service);
-    result = true;
-  }
-
-  return result;
+  boost::shared_ptr<Ekiga::Spark> spark(new AVAHIPUBSpark);
+  kickstart.add_spark (spark);
 }
