@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2008 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -72,8 +72,7 @@ Avahi::PresencePublisher::PresencePublisher (Ekiga::ServiceCore& core_,
   client(NULL), group(NULL)
 {
   display_name = details.get_display_name ();
-  details.updated.connect (sigc::mem_fun (this,
-					  &Avahi::PresencePublisher::on_details_updated));
+  details.updated.connect (boost::bind (&Avahi::PresencePublisher::on_details_updated, this));
   name = avahi_strdup (display_name.c_str ());
   glib_poll = avahi_glib_poll_new (NULL, G_PRIORITY_DEFAULT);
   create_client ();
@@ -286,10 +285,10 @@ Avahi::PresencePublisher::prepare_txt_record ()
 
   result = avahi_string_list_add_printf (result,
 					 "presence=%s",
-					 details.get_short_status ().c_str ());
+					 details.get_presence ().c_str ());
   result = avahi_string_list_add_printf (result,
 					 "status=%s",
-					 details.get_long_status ().c_str ());
+					 details.get_status ().c_str ());
   result = avahi_string_list_add_printf (result,
 					 "software=%s %s",
 					 PACKAGE_NAME, PACKAGE_VERSION);
