@@ -40,6 +40,8 @@
 
 #include "avahi-heap.h"
 
+#define DEBUG 0
+
 static void
 avahi_client_callback (AvahiClient *client,
 		       AvahiClientState state,
@@ -79,11 +81,10 @@ avahi_resolver_callback (AvahiServiceResolver *resolver,
 			 AvahiLookupResultFlags flags,
 			 void *data)
 {
-  if (!(flags & AVAHI_LOOKUP_RESULT_LOCAL))
-    ((Avahi::Heap *)data)->ResolverCallback (resolver, interface, protocol,
-                                             event, name, type, domain,
-                                             host_name, address, port,
-                                             txt, flags);
+  ((Avahi::Heap *)data)->ResolverCallback (resolver, interface, protocol,
+					   event, name, type, domain,
+					   host_name, address, port,
+					   txt, flags);
 }
 
 
@@ -106,7 +107,10 @@ Avahi::Heap::Heap (Ekiga::ServiceCore &_core): core(_core)
   client = avahi_client_new (poll_api, (AvahiClientFlags)AVAHI_CLIENT_NO_FAIL,
 			     avahi_client_callback, this,
 			     &error);
-  /* if (client == NULL); FIXME: better error reporting? */
+#if DEBUG
+  if (client == NULL)
+    std::cout << __PRETTY_FUNCTION__ << " client is NULL!" << std::endl;
+#endif
 }
 
 Avahi::Heap::~Heap ()
@@ -142,6 +146,8 @@ void
 Avahi::Heap::ClientCallback (AvahiClient *_client,
 			     AvahiClientState state)
 {
+  AvahiServiceBrowser* browser = NULL;
+
   /* this is the good client pointer */
   client = _client;
 
@@ -150,30 +156,42 @@ Avahi::Heap::ClientCallback (AvahiClient *_client,
     /* bad, bad: free the client and try to get another one... but
      * won't I tax the box?
      */
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " AVAHI_CLIENT_FAILURE" << std::endl;
+#endif
     if (client != NULL)
       avahi_client_free (client);
     client = NULL;
-    ; // FIXME: better error reporting
     break;
   case AVAHI_CLIENT_S_RUNNING:
     /* this may not be the final valid browser pointer...
      * we'll take what our callback gets
      */
-    avahi_service_browser_new (client,
-			       AVAHI_IF_UNSPEC,
-			       AVAHI_PROTO_UNSPEC,
-			       "_sip._udp", NULL,
-			       (AvahiLookupFlags)0,
-			       avahi_browser_callback,
-			       this);
-    /* if (browser == NULL) FIXME: better error reporting */
+    browser = avahi_service_browser_new (client,
+					 AVAHI_IF_UNSPEC,
+					 AVAHI_PROTO_UNSPEC,
+					 "_sip._udp", NULL,
+					 (AvahiLookupFlags)0,
+					 avahi_browser_callback,
+					 this);
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " AVAHI_CLIENT_S_RUNNING" << std::endl;
+    if (browser == NULL)
+      std::cout << "but NULL browser!" << std::endl;
+#endif
     break;
   case AVAHI_CLIENT_CONNECTING:
   case AVAHI_CLIENT_S_REGISTERING:
   case AVAHI_CLIENT_S_COLLISION:
     /* do nothing */
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " OTHER" << std::endl;
+#endif
     break;
   default:
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " SHOULDN'T HAPPEN" << std::endl;
+#endif
     /* shouldn't happen */
     break;
   }
@@ -202,25 +220,55 @@ Avahi::Heap::BrowserCallback (AvahiServiceBrowser *browser,
 					   AVAHI_PROTO_UNSPEC,
 					   (AvahiLookupFlags)0,
 					   avahi_resolver_callback, this);
-    /* if (resolver == NULL) FIXME: better error reporting */
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " AVAHI_BROWSER_NEW" << std::endl;
+#endif
+    if (resolver == NULL)
+      std::cout << "resolver is NULL!" << std::endl;
     break;
 
   case AVAHI_BROWSER_REMOVE:
-    visit_presentities (sigc::bind (sigc::mem_fun (this, &Avahi::Heap::remover), name));
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " AVAHI_BROWSER_REMOVE" << std::endl;
+#endif
+    {
+      bool found = false;
+      for (iterator iter = begin ();
+	   !found && iter != end ();
+	   ++iter) {
+
+	if ((*iter)->get_name () == name) {
+
+	  found = true;
+	  (*iter)->removed ();
+	}
+      }
+    }
     break;
   case AVAHI_BROWSER_CACHE_EXHAUSTED:
     // FIXME: do I care?
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " AVAHI_BROWSER_CACHE_EXHAUSTED" << std::endl;
+#endif
     break;
   case AVAHI_BROWSER_ALL_FOR_NOW:
     // FIXME: do I care?
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " AVAHI_BROWSER_ALL_FOR_NOW" << std::endl;
+#endif
     break;
   case AVAHI_BROWSER_FAILURE:
-      avahi_service_browser_free (browser);
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " AVAHI_BROWSER_FAILURE" << std::endl;
+#endif
+    avahi_service_browser_free (browser);
     browser = NULL;
-    ; // FIXME: better error reporting
     break;
   default:
     /* shouldn't happen */
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " SHOULDN'T HAPPEN" << std::endl;
+#endif
     break;
   }
 }
@@ -232,11 +280,12 @@ public:
   resolver_callback_helper (const std::string name_): name(name_)
   {}
 
-  bool test (gmref_ptr<Ekiga::URIPresentity> presentity_)
+  bool operator() (Ekiga::PresentityPtr pres_)
   {
-    bool result;
+    boost::shared_ptr<Ekiga::URIPresentity> presentity_ = boost::dynamic_pointer_cast<Ekiga::URIPresentity> (pres_);
+    bool result = true;
 
-    if (presentity_->get_name () == name) {
+    if (presentity_ && presentity_->get_name () == name) {
 
       presentity = presentity_;
       result = false;
@@ -244,11 +293,11 @@ public:
     return result;
   }
 
-  gmref_ptr<Ekiga::URIPresentity> found_presentity () const
+  boost::shared_ptr<Ekiga::URIPresentity> found_presentity () const
   { return presentity; }
 
 private:
-  gmref_ptr<Ekiga::URIPresentity> presentity;
+  boost::shared_ptr<Ekiga::URIPresentity> presentity;
   const std::string name;
 };
 
@@ -264,7 +313,7 @@ Avahi::Heap::ResolverCallback (AvahiServiceResolver *resolver,
 			       const AvahiAddress */*address*/,
 			       uint16_t port,
 			       AvahiStringList *txt,
-			       AvahiLookupResultFlags /*flags*/)
+			       AvahiLookupResultFlags flags)
 {
   std::string name;
   std::string software;
@@ -273,9 +322,24 @@ Avahi::Heap::ResolverCallback (AvahiServiceResolver *resolver,
   gchar *url = NULL;
   AvahiStringList *txt_tmp = NULL;
 
+  // filter out seeing ourselves
+  // FIXME: doesn't it hide other people on the same box too?
+  if (flags & AVAHI_LOOKUP_RESULT_LOCAL) {
+
+    avahi_service_resolver_free (resolver);
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " LOCAL RESULT" << std::endl;
+#endif
+    return;
+  }
+
   switch (event) {
 
   case AVAHI_RESOLVER_FOUND: {
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " AVAHI_RESOLVER_FOUND" << std::endl;
+#endif
+
     name = name_;
     for (txt_tmp = txt;  txt_tmp != NULL; txt_tmp = txt_tmp->next) {
 
@@ -301,12 +365,12 @@ Avahi::Heap::ResolverCallback (AvahiServiceResolver *resolver,
     }
 
     resolver_callback_helper helper(name);
-    visit_presentities (sigc::mem_fun (helper, &resolver_callback_helper::test));
+    visit_presentities (boost::ref (helper));
     if (helper.found_presentity ()) {
 
       /* known contact has been updated */
-      presence_received.emit (helper.found_presentity ()->get_uri (), presence);
-      status_received.emit (helper.found_presentity ()->get_uri (), status);
+      presence_received (helper.found_presentity ()->get_uri (), presence);
+      status_received (helper.found_presentity ()->get_uri (), status);
     } else {
 
       /* ok, this is a new contact */
@@ -318,37 +382,28 @@ Avahi::Heap::ResolverCallback (AvahiServiceResolver *resolver,
 
 	groups.insert (_("Neighbours"));
 	url = g_strdup_printf ("%s:neighbour@%s:%d", broken[1], host_name, port);
-	gmref_ptr<Ekiga::URIPresentity> presentity (new Ekiga::URIPresentity (core, name, url, groups));
-	status_received.emit (url, status);
-	presence_received.emit (url, presence);
+	boost::shared_ptr<Ekiga::URIPresentity> presentity (new Ekiga::URIPresentity (core, name, url, groups));
+	status_received (url, status);
+	presence_received (url, presence);
 	add_presentity (presentity);
 	g_free (url);
       }
       g_strfreev (broken);
     }
+    avahi_service_resolver_free (resolver);
     break;}
   case AVAHI_RESOLVER_FAILURE:
 
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " AVAHI_RESOLVER_FAILURE" << std::endl;
+#endif
     avahi_service_resolver_free (resolver);
-    /* FIXME: better error reporting */
     break;
   default:
     /* shouldn't happen */
+#if DEBUG
+    std::cout << __PRETTY_FUNCTION__ << " SHOULDN'T HAPPEN" << std::endl;
+#endif
     break;
   }
 }
-
-bool
-Avahi::Heap::remover (Ekiga::PresentityPtr presentity,
-		      const std::string name)
-{
-  bool result = true;
-
-  if (presentity->get_name () == name) {
-
-    result = false;
-    presentity->removed.emit ();
-  }
-
-  return result;
-}
