@@ -53,7 +53,7 @@ namespace History
 
   class Book:
     public Ekiga::BookImpl<Contact>,
-    public sigc::trackable
+    public boost::signals::trackable
   {
   public:
 
@@ -74,8 +74,6 @@ namespace History
     const std::string get_icon () const
     { return "local-object"; }
 
-    void set_search_filter (std::string);
-
     /* more specific api */
 
     void add (const std::string & name,
@@ -86,7 +84,7 @@ namespace History
 
     void clear ();
 
-    sigc::signal0<void> cleared;
+    boost::signal0<void> cleared;
 
   private:
 
@@ -98,18 +96,18 @@ namespace History
 
     void common_add (Contact &contact);
 
-    void on_missed_call (gmref_ptr<Ekiga::CallManager> manager,
-			 gmref_ptr<Ekiga::Call> call);
+    void on_missed_call (boost::shared_ptr<Ekiga::CallManager> manager,
+			 boost::shared_ptr<Ekiga::Call> call);
 
-    void on_cleared_call (gmref_ptr<Ekiga::CallManager> manager,
-			  gmref_ptr<Ekiga::Call> call,
+    void on_cleared_call (boost::shared_ptr<Ekiga::CallManager> manager,
+			  boost::shared_ptr<Ekiga::Call> call,
 			  std::string message);
 
     Ekiga::ServiceCore &core;
-    std::tr1::shared_ptr<xmlDoc> doc;
+    boost::shared_ptr<xmlDoc> doc;
   };
 
-  typedef gmref_ptr<Book> BookPtr;
+  typedef boost::shared_ptr<Book> BookPtr;
 
 /**
  * @}
