@@ -57,6 +57,8 @@ public:
 
     typedef enum { SIP, Ekiga, DiamondCard, H323 } Type;
 
+    typedef enum { Processing, Registered, Unregistered, RegistrationFailed, UnregistrationFailed } RegistrationState;
+
     Account (Ekiga::ServiceCore & core, 
              const std::string & account);
 
@@ -74,8 +76,12 @@ public:
 
     const std::string get_name () const;
 
+    const std::string get_status () const;
+
     const std::string get_aor () const;
 
+    Type get_type () const;
+
     /** Returns the protocol name of the Opal::Account.
      * This function is purely virtual and should be implemented by the
      * Ekiga::Account descendant.
@@ -122,10 +128,10 @@ public:
 
     bool is_enabled () const;
 
-    bool is_limited () const;
-
     bool is_active () const;
 
+    bool is_limited () const;
+
     void remove ();
 
     void edit ();
@@ -134,23 +140,36 @@ public:
 
     const std::string as_string () const;
 
-    sigc::signal0<void> trigger_saving;
+    boost::signal0<void> trigger_saving;
+
+    /* This method is public to be called by an opal endpoint, which will push
+     * this Opal::Account's new registration state
+     * Notice : it's very wrong to make that a const method, but Opal seems to
+     * want its Register method to take a const account...
+     */
+    void handle_registration_event (RegistrationState state_,
+				    const std::string info) const;
+
+    /* This method is public to be called by an opal endpoint, which will push
+     * this Opal::Account's message waiting information
+     */
+    void handle_message_waiting_information (const std::string info);
+
  
 private:
     void on_edit_form_submitted (bool submitted,
 				 Ekiga::Form &result);
     void on_consult (const std::string url);
-    
-    // Triggered for our own event
-    void on_registration_event (Ekiga::Account::RegistrationState state, std::string info);
 
+    mutable RegistrationState state;
     bool dead;
-    bool active;
     bool enabled;
-    bool limited;
+    mutable bool limited;
     unsigned timeout;
     std::string aid;
     std::string name;
+    mutable std::string status;
+    int message_waiting_number;
     std::string protocol_name;
     std::string host;
     std::string username;
@@ -161,7 +180,7 @@ private:
     Ekiga::ServiceCore & core;
   };
 
-  typedef gmref_ptr<Account> AccountPtr;
+  typedef boost::shared_ptr<Account> AccountPtr;
 
   /**
    * @}
