@@ -56,8 +56,11 @@
 #include "presence-core.h"
 #include "call-manager.h"
 #include "call.h"
+#include "opal-call.h"
 
-#include <sigc++/sigc++.h>
+#include <boost/signals.hpp>
+#include <boost/bind.hpp>
+#include <boost/enable_shared_from_this.hpp>
 #include <string>
 
 
@@ -66,9 +69,11 @@ class GMPCSSEndpoint;
 
 namespace Opal {
 
-  class CallManager : public Ekiga::Service,
-                      public Ekiga::CallManager,
-                      public OpalManager
+  class CallManager :
+    public boost::enable_shared_from_this<CallManager>,
+    public Ekiga::Service,
+    public Ekiga::CallManager,
+    public OpalManager
   {
     PCLASSINFO(CallManager, OpalManager);
 
@@ -103,6 +108,9 @@ public:
     void set_reject_delay (unsigned delay);
     unsigned get_reject_delay () const;
 
+    void set_auto_answer (bool enabled);
+    bool get_auto_answer () const;
+
     void set_codecs (Ekiga::CodecList & codecs); 
     const Ekiga::CodecList & get_codecs () const;
 
@@ -128,6 +136,9 @@ public:
     void get_tcp_ports (unsigned & min_port, 
                         unsigned & max_port) const;
 
+    void get_rtp_tos (unsigned &tos) const;
+    void set_rtp_tos (unsigned tos);
+
     void set_stun_server (const std::string & server);
     void set_stun_enabled (bool);
 
@@ -152,7 +163,9 @@ public:
     void get_video_options (VideoOptions & options) const;
 
 private:
+    void create_call_in_main (Opal::Call* call);
     OpalCall *CreateCall (void *uri);
+    void emit_removed_in_main (Ekiga::Call* call);
     void DestroyCall (OpalCall *);
 
     bool OnOpenMediaStream (OpalConnection &,
@@ -187,6 +200,7 @@ private:
     bool unconditional_forward;
     bool forward_on_no_answer;
     bool stun_enabled;
+    bool auto_answer;
   };
 };
 #endif
