@@ -48,6 +48,24 @@
 
 using namespace Opal;
 
+static void
+strip_special_chars (std::string& str, char* special_chars, bool start)
+{
+  std::string::size_type idx;
+
+  unsigned i = 0;
+  while (i < strlen (special_chars)) {
+    idx = str.find_first_of (special_chars[i]);
+    if (idx != std::string::npos) {
+      if (start)
+        str = str.substr (idx+1);
+      else
+        str = str.substr (0, idx);
+    }
+    i++;
+  }
+}
+
 class CallSetup : public PThread
 {
   PCLASSINFO(CallSetup, PThread);
@@ -73,9 +91,11 @@ private:
 };
 
 
-Opal::Call::Call (OpalManager & _manager, Ekiga::ServiceCore & _core)
-  : OpalCall (_manager), Ekiga::Call (), core (_core),
-    call_setup(false),outgoing(true),jitter(0)
+Opal::Call::Call (OpalManager& _manager,
+		  const Ekiga::ServiceCore& _core,
+		  const std::string& uri)
+  : OpalCall (_manager), Ekiga::Call (), core (_core), remote_uri (uri),
+    call_setup(false), jitter(0), outgoing(false)
 {
   re_a_bytes = tr_a_bytes = re_v_bytes = tr_v_bytes = 0.0;
   last_v_tick = last_a_tick = PTime ();
@@ -112,19 +132,10 @@ Opal::Call::hangup ()
 void
 Opal::Call::answer ()
 {
-  PSafePtr<OpalConnection> connection = NULL;
-  int i = 0;
-
   if (!is_outgoing () && !IsEstablished ()) {
-
-    do {
-
-      connection = GetConnection (i);
-      i++;
-    }  while (!PIsDescendant(&(*connection), OpalPCSSConnection));
-
-    if (PIsDescendant(&(*connection), OpalPCSSConnection)) {
-      PDownCast (OpalPCSSConnection, &(*connection))->AcceptIncoming ();
+    PSafePtr<OpalPCSSConnection> connection = GetConnectionAs<OpalPCSSConnection>();
+    if (connection != NULL) {
+      connection->AcceptIncoming();
     }
   }
 }
@@ -133,17 +144,8 @@ Opal::Call::answer ()
 void
 Opal::Call::transfer (std::string uri)
 {
-  PSafePtr<OpalConnection> connection = NULL;
-
-  int i = 0;
-
-  do {
-
-    connection = GetConnection (i);
-    i++;
-  }  while (PIsDescendant(&(*connection), OpalPCSSConnection));
-
-  if (connection)
+  PSafePtr<OpalConnection> connection = get_remote_connection ();
+  if (connection != NULL)
     connection->TransferConnection (uri);
 }
 
@@ -151,20 +153,11 @@ Opal::Call::transfer (std::string uri)
 void
 Opal::Call::toggle_hold ()
 {
-  PSafePtr<OpalConnection> connection = NULL;
-
   bool on_hold = false;
-  int i = 0;
+  PSafePtr<OpalConnection> connection = get_remote_connection ();
+  if (connection != NULL) {
 
-  do {
-
-    connection = GetConnection (i);
-    i++;
-  }  while (PIsDescendant(&(*connection), OpalPCSSConnection));
-
-  if (connection) {
-
-    on_hold = connection->IsConnectionOnHold ();
+    on_hold = connection->IsConnectionOnHold (false);
     if (!on_hold)
       connection->HoldConnection ();
     else
@@ -177,20 +170,12 @@ void
 Opal::Call::toggle_stream_pause (StreamType type)
 {
   OpalMediaStreamPtr stream = NULL;
-  PSafePtr<OpalConnection> connection = NULL;
   PString codec_name;
   std::string stream_name;
 
   bool paused = false;
 
-  int i = 0;
-
-  do {
-
-    connection = GetConnection (i);
-    i++;
-  }  while (PIsDescendant(&(*connection), OpalPCSSConnection));
-
+  PSafePtr<OpalConnection> connection = get_remote_connection ();
   if (connection != NULL) {
 
     stream = connection->GetMediaStream ((type == Audio) ? OpalMediaType::Audio () : OpalMediaType::Video (), false);
@@ -202,9 +187,9 @@ Opal::Call::toggle_stream_pause (StreamType type)
       stream->SetPaused (!paused);
 
       if (paused)
-	Ekiga::Runtime::run_in_main (sigc::bind (stream_resumed, stream_name, type));
+	Ekiga::Runtime::run_in_main (boost::bind (boost::ref (stream_resumed), stream_name, type));
       else
-	Ekiga::Runtime::run_in_main (sigc::bind (stream_paused, stream_name, type));
+	Ekiga::Runtime::run_in_main (boost::bind (boost::ref (stream_paused), stream_name, type));
     }
   }
 }
@@ -213,18 +198,10 @@ Opal::Call::toggle_stream_pause (StreamType type)
 void
 Opal::Call::send_dtmf (const char dtmf)
 {
-  PSafePtr<OpalConnection> connection = NULL;
-
-  int i = 0;
-
-  do {
-
-    connection = GetConnection (i);
-    i++;
-  }  while (PIsDescendant(&(*connection), OpalPCSSConnection));
-
-  if (connection != NULL)
+  PSafePtr<OpalConnection> connection = get_remote_connection ();
+  if (connection != NULL) {
     connection->SendUserInputTone (dtmf, 180);
+  }
 }
 
 
@@ -305,28 +282,25 @@ Opal::Call::get_start_time () const
 bool 
 Opal::Call::is_outgoing () const
 {
-  return outgoing; 
+  return outgoing;
 }
 
 
 void
 Opal::Call::parse_info (OpalConnection & connection)
 {
-  char special_chars [] = "([;=";
-  int i = 0;
-  std::string::size_type idx;
+  char start_special_chars [] = "$";
+  char end_special_chars [] = "([;=";
+  
   std::string l_party_name;
   std::string r_party_name;
   std::string app;
 
-  remote_uri = (const char *) connection.GetRemotePartyCallbackURL ();
   if (!PIsDescendant(&connection, OpalPCSSConnection)) {
 
-    outgoing = connection.IsOriginating ();
+    remote_uri = (const char *) connection.GetRemotePartyAddress ();
 
-    remote_uri = (const char *) connection.GetRemotePartyCallbackURL ();
-
-    l_party_name = (const char *) connection.GetCalledPartyURL ();
+    l_party_name = (const char *) connection.GetLocalPartyName ();
     r_party_name = (const char *) connection.GetRemotePartyName ();
     app = (const char *) connection.GetRemoteProductInfo ().AsString ();
     start_time = connection.GetConnectionStartTime ();
@@ -339,22 +313,13 @@ Opal::Call::parse_info (OpalConnection & connection)
       remote_party_name = r_party_name;
     if (!app.empty ())
       remote_application = app;
+    
+    strip_special_chars (remote_party_name, end_special_chars, false);
+    strip_special_chars (remote_application, end_special_chars, false);
+    strip_special_chars (remote_uri, end_special_chars, false);
 
-    while (i < 3) {
-
-      idx = remote_party_name.find_first_of (special_chars [i]);
-      if (idx != std::string::npos)
-        remote_party_name = remote_party_name.substr (0, idx);
-
-      idx = remote_application.find_first_of (special_chars [i]);
-      if (idx != std::string::npos)
-        remote_application = remote_application.substr (0, idx);
-
-      idx = remote_uri.find_first_of (special_chars [i]);
-      if (idx != std::string::npos)
-        remote_uri = remote_uri.substr (0, idx);
-      i++;
-    }
+    strip_special_chars (remote_party_name, start_special_chars, true);
+    strip_special_chars (remote_uri, start_special_chars, true);
   }
 }
 
@@ -370,7 +335,7 @@ Opal::Call::OnEstablished (OpalConnection & connection)
   if (!PIsDescendant(&connection, OpalPCSSConnection)) {
 
     parse_info (connection);
-    Ekiga::Runtime::emit_signal_in_main (established);
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Call::emit_established_in_main, this));
   }
 
   if (PIsDescendant(&connection, OpalRTPConnection)) {
@@ -428,7 +393,7 @@ Opal::Call::OnCleared ()
       && !is_outgoing ()
       && GetCallEndReason () != OpalConnection::EndedByAnswerDenied) {
 
-    Ekiga::Runtime::emit_signal_in_main (missed);
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Call::emit_missed_in_main, this));
   }
   else {
 
@@ -459,6 +424,7 @@ Opal::Call::OnCleared ()
       reason = _("Could not connect to remote host");
       break;
     case OpalConnection::EndedByGatekeeper :
+    case OpalConnection::EndedByGkAdmissionFailed :
       reason = _("The Gatekeeper cleared the call");
       break;
     case OpalConnection::EndedByNoUser :
@@ -504,13 +470,12 @@ Opal::Call::OnCleared ()
     case OpalConnection::EndedByNoRingBackTone:
     case OpalConnection::EndedByOutOfService:
     case OpalConnection::EndedByAcceptingCallWaiting:
-    case OpalConnection::EndedWithQ931Code:
     case OpalConnection::NumCallEndReasons:
     default :
       reason = _("Call completed");
     }
 
-    Ekiga::Runtime::emit_signal_in_main (cleared, reason);
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Call::emit_cleared_in_main, this, reason));
   }
 }
 
@@ -530,13 +495,14 @@ Opal::Call::OnAnswerCall (OpalConnection & connection,
 PBoolean
 Opal::Call::OnSetUp (OpalConnection & connection)
 {
+  outgoing = !IsNetworkOriginated ();
   parse_info (connection);
 
-  Ekiga::Runtime::emit_signal_in_main (setup);
+  Ekiga::Runtime::run_in_main (boost::bind (&Opal::Call::emit_setup_in_main, this));
   call_setup = true;
 
-  cleared.connect (sigc::mem_fun (this, &Opal::Call::on_cleared_call));
-  missed.connect (sigc::mem_fun (this, &Opal::Call::on_missed_call));
+  cleared.connect (boost::bind (&Opal::Call::on_cleared_call, this, _1));
+  missed.connect (boost::bind (&Opal::Call::on_missed_call, this));
 
   new CallSetup (*this, connection);
 
@@ -548,7 +514,7 @@ PBoolean
 Opal::Call::OnAlerting (OpalConnection & connection)
 {
   if (!PIsDescendant(&connection, OpalPCSSConnection))
-    Ekiga::Runtime::emit_signal_in_main (ringing);
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Call::emit_ringing_in_main, this));
 
   return OpalCall::OnAlerting (connection);
 }
@@ -560,9 +526,9 @@ Opal::Call::OnHold (OpalConnection & /*connection*/,
                     bool on_hold)
 {
   if (on_hold)
-    Ekiga::Runtime::emit_signal_in_main (held);
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Call::emit_held_in_main, this));
   else
-    Ekiga::Runtime::emit_signal_in_main (retrieved);
+    Ekiga::Runtime::run_in_main (boost::bind (&Opal::Call::emit_retrieved_in_main, this));
 }
 
 
@@ -577,7 +543,7 @@ Opal::Call::OnOpenMediaStream (OpalMediaStream & stream)
   std::transform (stream_name.begin (), stream_name.end (), stream_name.begin (), (int (*) (int)) toupper);
   is_transmitting = !stream.IsSource ();
 
-  Ekiga::Runtime::run_in_main (sigc::bind (stream_opened, stream_name, type, is_transmitting));
+  Ekiga::Runtime::run_in_main (boost::bind (boost::ref (stream_opened), stream_name, type, is_transmitting));
 }
 
 
@@ -592,7 +558,7 @@ Opal::Call::OnClosedMediaStream (OpalMediaStream & stream)
   std::transform (stream_name.begin (), stream_name.end (), stream_name.begin (), (int (*) (int)) toupper);
   is_transmitting = !stream.IsSource ();
 
-  Ekiga::Runtime::run_in_main (sigc::bind (stream_closed, stream_name, type, is_transmitting));
+  Ekiga::Runtime::run_in_main (boost::bind (boost::ref (stream_closed), stream_name, type, is_transmitting));
 }
 
 
@@ -666,19 +632,12 @@ void
 Opal::Call::OnNoAnswerTimeout (PTimer &,
                                INT) 
 {
-  PSafePtr<OpalConnection> connection = NULL;
-  int i = 0;
-
   if (!is_outgoing ()) {
 
     if (!forward_uri.empty ()) {
 
-      do {
-        connection = GetConnection (i);
-        i++;
-      }  while (PIsDescendant(&(*connection), OpalPCSSConnection));
-
-      if (!PIsDescendant(&(*connection), OpalPCSSConnection)) 
+      PSafePtr<OpalConnection> connection = get_remote_connection ();
+      if (connection != NULL)
         connection->ForwardCall (forward_uri);
     }
     else
@@ -699,3 +658,45 @@ Opal::Call::on_missed_call ()
 {
   OpalCall::OnCleared ();
 }
+
+void
+Opal::Call::emit_established_in_main ()
+{
+  established ();
+}
+
+void
+Opal::Call::emit_missed_in_main ()
+{
+  missed ();
+}
+
+void
+Opal::Call::emit_cleared_in_main (const std::string reason)
+{
+  cleared (reason);
+}
+
+void
+Opal::Call::emit_setup_in_main ()
+{
+  setup ();
+}
+
+void
+Opal::Call::emit_ringing_in_main ()
+{
+  ringing ();
+}
+
+void
+Opal::Call::emit_held_in_main ()
+{
+  held ();
+}
+
+void
+Opal::Call::emit_retrieved_in_main ()
+{
+  retrieved ();
+}
