@@ -52,7 +52,7 @@ struct _AddressBookWindowPrivate
   _AddressBookWindowPrivate (Ekiga::ContactCore & _core):core (_core) { }
 
   Ekiga::ContactCore & core;
-  std::vector<sigc::connection> connections;
+  std::vector<boost::signals::connection> connections;
   GtkWidget *tree_view;
   GtkWidget *notebook;
   GtkTreeSelection *selection;
@@ -76,9 +76,7 @@ enum {
   DIALOG_COLUMN_SOURCE_POINTER
 };
 
-
-static GObjectClass *parent_class = NULL;
-
+G_DEFINE_TYPE (AddressBookWindow, addressbook_window, GM_TYPE_WINDOW);
 
 /*
  * Callbacks
@@ -92,6 +90,13 @@ static GObjectClass *parent_class = NULL;
 static void on_core_updated (gpointer data);
 
 
+/* DESCRIPTION  : Called at startup to populate the window
+ * BEHAVIOR     :
+ * PRE          : The given GtkWidget pointer must be an addressbook window.
+ */
+static bool on_visit_sources (Ekiga::SourcePtr source,
+			      gpointer data);
+
 /* DESCRIPTION  : Called at startup to populate the window
  * BEHAVIOR     : 
  * PRE          : The given GtkWidget pointer must be an SearchBook GObject.
@@ -142,7 +147,7 @@ static void on_book_updated (Ekiga::SourcePtr source,
  * BEHAVIOR     : Runs the form request in gtk+
  * PRE          : The given pointer is the parent window for the form.
  */
-static bool on_handle_questions (Ekiga::FormRequest *request,
+static bool on_handle_questions (Ekiga::FormRequestPtr request,
 				 gpointer data);
 
 /* DESCRIPTION  : Called when a view of a Book has been updated,
@@ -239,7 +244,7 @@ on_core_updated (gpointer data)
 
   item = gtk_image_menu_item_new_from_stock (GTK_STOCK_CLOSE, self->priv->accel);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu_builder.menu), item);
-  g_signal_connect_swapped (G_OBJECT (item), "activate",
+  g_signal_connect_swapped (item, "activate",
                             G_CALLBACK (gtk_widget_hide),
                             (gpointer) self);
 
@@ -249,13 +254,19 @@ on_core_updated (gpointer data)
   gtk_widget_show_all (menu_builder.menu);
 }
 
+static bool
+on_visit_sources (Ekiga::SourcePtr source,
+		  gpointer data)
+{
+  on_source_added (source, data);
+  return true;
+}
 
 static void
 on_source_added (Ekiga::SourcePtr source,
 		 gpointer data)
 {
-  source->visit_books (sigc::bind (sigc::ptr_fun (visit_books),
-				   source, data));
+  source->visit_books (boost::bind (&visit_books, _1, source, data));
 }
 
 
@@ -296,10 +307,10 @@ on_book_updated (Ekiga::SourcePtr /*source*/,
 }
 
 static bool
-on_handle_questions (Ekiga::FormRequest *request,
+on_handle_questions (Ekiga::FormRequestPtr request,
 		     gpointer data)
 {
-  FormDialog dialog (*request, GTK_WIDGET (data));
+  FormDialog dialog (request, GTK_WIDGET (data));
 
   dialog.run ();
 
@@ -404,7 +415,7 @@ on_book_clicked (GtkWidget *tree_view,
             gtk_menu_popup (GTK_MENU (menu_builder.menu),
                             NULL, NULL, NULL, NULL,
                             event->button, event->time);
-            g_signal_connect (G_OBJECT (menu_builder.menu), "hide",
+            g_signal_connect (menu_builder.menu, "hide",
                               G_CALLBACK (g_object_unref),
                               (gpointer) menu_builder.menu);
           }
@@ -435,35 +446,29 @@ addressbook_window_add_book (AddressBookWindow *self,
   page = gtk_notebook_append_page (GTK_NOTEBOOK (self->priv->notebook),
                                    view, NULL);
 
-#if GTK_CHECK_VERSION(2,18,0)
   if (gtk_widget_get_visible (GTK_WIDGET (self)))
-#else
-  if (GTK_WIDGET_VISIBLE (self))
-#endif
     gtk_widget_show_all (view);
 
   g_signal_connect (view, "updated", G_CALLBACK (on_view_updated), self);
 
   icon = gtk_widget_render_icon (GTK_WIDGET (self->priv->tree_view),
 				 book->get_icon ().c_str (),
-				 GTK_ICON_SIZE_MENU, NULL);
+				 GTK_ICON_SIZE_MENU, NULL); 
 
   store = gtk_tree_view_get_model (GTK_TREE_VIEW (self->priv->tree_view));
   gtk_tree_store_append (GTK_TREE_STORE (store), &iter, NULL);
   gtk_tree_store_set (GTK_TREE_STORE (store), &iter,
-                      COLUMN_PIXBUF, icon,
+                      COLUMN_PIXBUF, icon, 
                       COLUMN_NAME, book->get_name ().c_str (),
-                      COLUMN_BOOK_POINTER, book.get (),
+                      COLUMN_BOOK_POINTER, book.get (), 
                       COLUMN_VIEW, view,
                       -1);
 
   if (!gtk_tree_selection_get_selected (self->priv->selection, &store, &iter)) {
-
+   
     gtk_tree_model_get_iter_first (store, &iter);
     gtk_tree_selection_select_iter (self->priv->selection, &iter);
   }
-
-  g_object_unref (icon);
 }
 
 
@@ -557,9 +562,7 @@ find_iter_for_book (AddressBookWindow *self,
 static void
 addressbook_window_dispose (GObject *obj)
 {
-  AddressBookWindow *self = NULL;
-
-  self = ADDRESSBOOK_WINDOW (obj);
+  AddressBookWindow *self = ADDRESSBOOK_WINDOW (obj);
 
   if (self->priv->menu_item_view) {
 
@@ -573,18 +576,16 @@ addressbook_window_dispose (GObject *obj)
     self->priv->menu_item_core = NULL;
   }
 
-  parent_class->dispose (obj);
+  G_OBJECT_CLASS (addressbook_window_parent_class)->dispose (obj);
 }
 
 
 static void
 addressbook_window_finalize (GObject *obj)
 {
-  AddressBookWindow *self = NULL;
+  AddressBookWindow *self = ADDRESSBOOK_WINDOW (obj);
 
-  self = ADDRESSBOOK_WINDOW (obj);
-
-  for (std::vector<sigc::connection>::iterator iter
+  for (std::vector<boost::signals::connection>::iterator iter
 	 = self->priv->connections.begin ();
        iter != self->priv->connections.end ();
        iter++)
@@ -592,52 +593,24 @@ addressbook_window_finalize (GObject *obj)
 
   delete self->priv;
 
-  parent_class->finalize (obj);
+  G_OBJECT_CLASS (addressbook_window_parent_class)->finalize (obj);
 }
 
+static void
+addressbook_window_init (G_GNUC_UNUSED AddressBookWindow* self)
+{
+  /* can't do anything here... we're waiting for a core :-/ */
+}
 
 static void
 addressbook_window_class_init (AddressBookWindowClass *klass)
 {
-  GObjectClass *gobject_class = NULL;
+  GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-  parent_class = (GObjectClass *) g_type_class_peek_parent (klass);
-
-  gobject_class = (GObjectClass *) klass;
   gobject_class->dispose = addressbook_window_dispose;
   gobject_class->finalize = addressbook_window_finalize;
 }
 
-
-GType
-addressbook_window_get_type ()
-{
-  static GType result = 0;
-
-  if (result == 0) {
-
-    static const GTypeInfo info = {
-      sizeof (AddressBookWindowClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) addressbook_window_class_init,
-      NULL,
-      NULL,
-      sizeof (AddressBookWindow),
-      0,
-      NULL,
-      NULL
-    };
-
-    result = g_type_register_static (GM_WINDOW_TYPE,
-                                     "AddressBookWindowType",
-                                     &info, (GTypeFlags) 0);
-  }
-
-  return result;
-}
-
-
 /*
  * Public API 
  */
@@ -646,7 +619,7 @@ addressbook_window_new (Ekiga::ContactCore &core)
 {
   AddressBookWindow *self = NULL;
 
-  sigc::connection conn;
+  boost::signals::connection conn;
 
   GtkWidget *menu_bar = NULL;
   GtkWidget *frame = NULL;
@@ -680,7 +653,7 @@ addressbook_window_new (Ekiga::ContactCore &core)
   gtk_menu_shell_append (GTK_MENU_SHELL (menu_bar),
                          self->priv->menu_item_core);
   g_object_ref (self->priv->menu_item_core);
-  conn = core.updated.connect (sigc::bind (sigc::ptr_fun (on_core_updated),
+  conn = core.updated.connect (boost::bind (&on_core_updated,
                                            (gpointer) self));
   self->priv->connections.push_back (conn);
   on_core_updated (self); // This will add static and dynamic actions
@@ -742,9 +715,9 @@ addressbook_window_new (Ekiga::ContactCore &core)
   self->priv->selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (self->priv->tree_view));
   gtk_tree_selection_set_mode (GTK_TREE_SELECTION (self->priv->selection),
                                GTK_SELECTION_SINGLE);
-  g_signal_connect (G_OBJECT (self->priv->selection), "changed",
+  g_signal_connect (self->priv->selection, "changed",
                     G_CALLBACK (on_book_selection_changed), self);
-  g_signal_connect (G_OBJECT (self->priv->tree_view), "event-after",
+  g_signal_connect (self->priv->tree_view, "event-after",
                     G_CALLBACK (on_book_clicked), self);
 
   /* The notebook containing the books */
@@ -754,25 +727,24 @@ addressbook_window_new (Ekiga::ContactCore &core)
                     G_CALLBACK (on_notebook_realize), self);
   gtk_paned_add2 (GTK_PANED (hpaned), self->priv->notebook);
 
-  conn = core.source_added.connect (sigc::bind (sigc::ptr_fun (on_source_added), (gpointer) self));
+  conn = core.source_added.connect (boost::bind (&on_source_added, _1, (gpointer) self));
   self->priv->connections.push_back (conn);
 
-  conn = core.book_updated.connect (sigc::bind (sigc::ptr_fun (on_book_updated),
+  conn = core.book_updated.connect (boost::bind (&on_book_updated, _1, _2,
                                                 (gpointer) self));
   self->priv->connections.push_back (conn);
-  conn = core.book_added.connect (sigc::bind (sigc::ptr_fun (on_book_added), 
+  conn = core.book_added.connect (boost::bind (&on_book_added, _1, _2,
                                               (gpointer) self));
   self->priv->connections.push_back (conn);
   conn =
-    core.book_removed.connect (sigc::bind (sigc::ptr_fun (on_book_removed), 
+    core.book_removed.connect (boost::bind (&on_book_removed, _1, _2,
                                            (gpointer) self));
   self->priv->connections.push_back (conn);
 
-  conn = core.questions.connect (sigc::bind (sigc::ptr_fun (on_handle_questions), (gpointer) self));
+  conn = core.questions.connect (boost::bind (&on_handle_questions, _1, (gpointer) self));
   self->priv->connections.push_back (conn);
 
-  core.visit_sources (sigc::bind_return (sigc::bind (sigc::ptr_fun (on_source_added),
-						     (gpointer) self), true));
+  core.visit_sources (boost::bind (on_visit_sources, _1, (gpointer) self));
 
   return GTK_WIDGET (self);
 }
