@@ -58,8 +58,8 @@ class ChatAreaHelper;
 struct _ChatAreaPrivate
 {
   Ekiga::Chat* chat;
-  sigc::connection connection;
-  gmref_ptr<ChatAreaHelper> helper;
+  boost::signals::connection connection;
+  boost::shared_ptr<ChatAreaHelper> helper;
   GmTextBufferEnhancer* enhancer;
   GtkWidget* smiley_menu;
 
@@ -80,7 +80,7 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-static GObjectClass* parent_class = NULL;
+G_DEFINE_TYPE (ChatArea, chat_area, GTK_TYPE_VPANED);
 
 /* declaration of internal api */
 
@@ -176,7 +176,7 @@ gm_chat_area_define_simple_text_tag (GtkTextBuffer* buffer,
 {
   va_list args;
   GtkTextTag* tag = NULL;
-  GmTextBufferEnhancerHelperIFace* helper = NULL;
+  GmTextBufferEnhancerHelper* helper = NULL;
   gchar* tmp_tagstring = NULL;
 
   g_return_if_fail (buffer != NULL);
@@ -368,19 +368,21 @@ on_extlink_tag_event (GtkTextTag* tag,
 			      g_strdup (link), g_free);
 
       menu_item = gtk_menu_item_new_with_label (_("Open link in browser"));
-      g_signal_connect_after (G_OBJECT (menu_item), "activate",
+      g_signal_connect_after (menu_item, "activate",
 			      G_CALLBACK (on_open_link_activate), menu);
       gtk_widget_show (menu_item);
       gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 
       menu_item = gtk_menu_item_new_with_label (_("Copy link"));
-      g_signal_connect_after (G_OBJECT (menu_item), "activate",
+      g_signal_connect_after (menu_item, "activate",
 			      G_CALLBACK (on_copy_link_activate), menu);
       gtk_widget_show (menu_item);
       gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 
       gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
 		      event->button.button, event->button.time);
+      g_object_ref_sink (menu);
+      g_object_unref (menu);
       break;
     }
 
@@ -431,9 +433,8 @@ on_extlink_tag_event (GtkTextTag* tag,
   case GDK_SETTING:
   case GDK_OWNER_CHANGE:
   case GDK_GRAB_BROKEN:
-#if GTK_CHECK_VERSION(2,14,0)
   case GDK_DAMAGE:
-#endif
+  case GDK_EVENT_LAST:
   default:
     result = FALSE; // nothing
     break; // nothing
@@ -627,7 +628,7 @@ chat_area_dispose (GObject* obj)
     self->priv->smiley_menu = NULL;
   }
 
-  parent_class->dispose (obj);
+  G_OBJECT_CLASS (chat_area_parent_class)->dispose (obj);
 }
 
 static void
@@ -647,7 +648,7 @@ chat_area_finalize (GObject* obj)
     self->priv->chat = NULL;
   }
 
-  parent_class->finalize (obj);
+  G_OBJECT_CLASS (chat_area_parent_class)->finalize (obj);
 }
 
 static void
@@ -688,8 +689,8 @@ chat_area_set_property (GObject* obj,
   case CHAT_AREA_PROP_CHAT:
     ptr = g_value_get_pointer (value);
     self->priv->chat = (Ekiga::Chat *)ptr;
-    self->priv->connection = self->priv->chat->removed.connect (sigc::bind (sigc::ptr_fun (on_chat_removed), self));
-    self->priv->helper = gmref_ptr<ChatAreaHelper>(new ChatAreaHelper (self));
+    self->priv->connection = self->priv->chat->removed.connect (boost::bind (&on_chat_removed, self));
+    self->priv->helper = boost::shared_ptr<ChatAreaHelper>(new ChatAreaHelper (self));
     self->priv->chat->connect (self->priv->helper);
     break;
 
@@ -700,18 +701,13 @@ chat_area_set_property (GObject* obj,
 }
 
 static void
-chat_area_class_init (gpointer g_class,
-		      G_GNUC_UNUSED gpointer class_data)
+chat_area_class_init (ChatAreaClass* klass)
 {
-  ChatAreaClass* chat_area_class = NULL;
-  GObjectClass* gobject_class = NULL;
+  GObjectClass* gobject_class = G_OBJECT_CLASS (klass);
   GParamSpec* spec = NULL;
 
-  parent_class = (GObjectClass*)g_type_class_peek_parent (g_class);
+  g_type_class_add_private (klass, sizeof (ChatAreaPrivate));
 
-  g_type_class_add_private (g_class, sizeof (ChatAreaPrivate));
-
-  gobject_class = (GObjectClass*)g_class;
   gobject_class->dispose = chat_area_dispose;
   gobject_class->finalize = chat_area_finalize;
   gobject_class->get_property = chat_area_get_property;
@@ -733,26 +729,18 @@ chat_area_class_init (gpointer g_class,
 		  NULL, NULL,
 		  g_cclosure_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
-
-  /* FIXME: is it useful? */
-  chat_area_class = (ChatAreaClass*)g_class;
-  chat_area_class->message_notice_event = NULL;
 }
 
 static void
-chat_area_init (GTypeInstance* instance,
-		G_GNUC_UNUSED gpointer g_class)
+chat_area_init (ChatArea* self)
 {
-  ChatArea* self = NULL;
   GtkTextBuffer* buffer = NULL;
-  GmTextBufferEnhancerHelperIFace* helper = NULL;
+  GmTextBufferEnhancerHelper* helper = NULL;
   GtkTextTag* tag = NULL;
   GtkTextIter iter;
   GtkWidget *frame = NULL;
   GtkWidget *sep = NULL;
 
-  self = (ChatArea*)instance;
-
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
 					    TYPE_CHAT_AREA,
 					    ChatAreaPrivate);
@@ -765,10 +753,10 @@ chat_area_init (GTypeInstance* instance,
   self->priv->scrolled_text_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy
     (GTK_SCROLLED_WINDOW (self->priv->scrolled_text_window),
-     GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
   self->priv->text_view = gtk_text_view_new ();
-  g_signal_connect (G_OBJECT (self->priv->text_view), "motion-notify-event",
+  g_signal_connect (self->priv->text_view, "motion-notify-event",
 		    G_CALLBACK (on_motion_notify_event), NULL);
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (self->priv->text_view));
 
@@ -806,7 +794,7 @@ chat_area_init (GTypeInstance* instance,
 				    "foreground", "blue",
 				    "underline", PANGO_UNDERLINE_SINGLE,
 				    NULL);
-  g_signal_connect (G_OBJECT (tag), "event",
+  g_signal_connect (tag, "event",
 		    G_CALLBACK (on_extlink_tag_event), NULL);
   {
     GdkCursor* cursor = gdk_cursor_new (GDK_HAND2);
@@ -908,7 +896,7 @@ chat_area_init (GTypeInstance* instance,
   gtk_button_set_image (GTK_BUTTON(smiley_chooser_button), smiley_button);
   gtk_button_set_relief (GTK_BUTTON(smiley_chooser_button), GTK_RELIEF_NONE);
   gtk_button_set_focus_on_click (GTK_BUTTON (smiley_chooser_button), FALSE);
-  g_signal_connect (G_OBJECT (smiley_chooser_button), "smiley_selected",
+  g_signal_connect (smiley_chooser_button, "smiley_selected",
 		    G_CALLBACK (on_smiley_selected), self);
   gtk_box_pack_start (GTK_BOX (bbox), smiley_chooser_button,
 		      FALSE, TRUE, 2);
@@ -921,7 +909,7 @@ chat_area_init (GTypeInstance* instance,
 			  (gpointer) "</b>", NULL);
   gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
   gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
-  g_signal_connect (G_OBJECT (button), "clicked",
+  g_signal_connect (button, "clicked",
 		    G_CALLBACK (on_font_changed), self);
   gtk_box_pack_start (GTK_BOX (bbox), button,
 		      FALSE, TRUE, 2);
@@ -935,7 +923,7 @@ chat_area_init (GTypeInstance* instance,
 			  (gpointer) "</i>", NULL);
   gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
   gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
-  g_signal_connect (G_OBJECT (button), "clicked",
+  g_signal_connect (button, "clicked",
 		    G_CALLBACK (on_font_changed), self);
   gtk_box_pack_start (GTK_BOX (bbox), button,
 		      FALSE, TRUE, 2);
@@ -949,7 +937,7 @@ chat_area_init (GTypeInstance* instance,
 			  (gpointer) "</u>", NULL);
   gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
   gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
-  g_signal_connect (G_OBJECT (button), "clicked",
+  g_signal_connect (button, "clicked",
 		    G_CALLBACK (on_font_changed), self);
   gtk_box_pack_start (GTK_BOX (bbox), button,
 		      FALSE, TRUE, 2);
@@ -962,7 +950,7 @@ chat_area_init (GTypeInstance* instance,
   gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (self->priv->message),
                                GTK_WRAP_WORD_CHAR);
   gtk_text_view_set_cursor_visible  (GTK_TEXT_VIEW (self->priv->message), true);
-  g_signal_connect (GTK_OBJECT (self->priv->message), "key-press-event",
+  g_signal_connect (self->priv->message, "key-press-event",
                     G_CALLBACK (message_activated_cb), self);
   gtk_box_pack_start (GTK_BOX (vbox), self->priv->message,
 		      TRUE, TRUE, 2);
@@ -970,46 +958,17 @@ chat_area_init (GTypeInstance* instance,
   gtk_widget_set_size_request (GTK_WIDGET (self->priv->message), 155, -1);
   gtk_widget_show_all (vbox);
 
-  g_signal_connect (G_OBJECT (self), "focus",
+  g_signal_connect (self, "focus",
 		    G_CALLBACK (on_chat_area_focus), NULL);
-  g_signal_connect (G_OBJECT (self), "grab-focus",
+  g_signal_connect (self, "grab-focus",
 		    G_CALLBACK (on_chat_area_grab_focus), self->priv->message);
   gtk_widget_grab_focus (self->priv->message);
 }
 
-
-GType
-chat_area_get_type ()
-{
-  static GType result = 0;
-
-  if (result == 0) {
-
-    static const GTypeInfo info = {
-      sizeof (ChatAreaClass),
-      NULL,
-      NULL,
-      chat_area_class_init,
-      NULL,
-      NULL,
-      sizeof (ChatArea),
-      0,
-      chat_area_init,
-      NULL
-    };
-
-    result = g_type_register_static (GTK_TYPE_VPANED,
-				     "ChatArea",
-				     &info, (GTypeFlags) 0);
-  }
-
-  return result;
-}
-
 /* public api */
 
 GtkWidget*
-chat_area_new (gmref_ptr<Ekiga::Chat> chat)
+chat_area_new (boost::shared_ptr<Ekiga::Chat> chat)
 {
   return (GtkWidget*)g_object_new (TYPE_CHAT_AREA,
 				   "chat", chat.get (),
