@@ -40,7 +40,6 @@
 
 #include "gmconfwidgets.h"
 
-#include <string.h>
 #include <libintl.h>
 
 enum {
@@ -171,11 +170,11 @@ gnome_prefs_entry_new (GtkWidget *table,
 
   g_free (conf_string);
 
-  g_signal_connect_after (G_OBJECT (entry), "focus-out-event",
+  g_signal_connect_after (entry, "focus-out-event",
 			  G_CALLBACK (entry_focus_changed),
 			  (gpointer)conf_key);
 
-  g_signal_connect_after (G_OBJECT (entry), "activate",
+  g_signal_connect_after (entry, "activate",
 			  G_CALLBACK (entry_activate_changed),
 			  (gpointer)conf_key);
 
@@ -233,7 +232,7 @@ gnome_prefs_toggle_new (GtkWidget *table,
   if (gpw && tooltip)
     gtk_widget_set_tooltip_text (toggle, tooltip);
 
-  g_signal_connect (G_OBJECT (toggle), "toggled",
+  g_signal_connect (toggle, "toggled",
 		    G_CALLBACK (toggle_changed), (gpointer) conf_key);
   
   gm_conf_notifier_add (conf_key, toggle_changed_nt, (gpointer) toggle);
@@ -310,7 +309,7 @@ gnome_prefs_scale_new (GtkWidget *table,
   if (gpw && tooltip)
     gtk_widget_set_tooltip_text (hscale, tooltip);
 
-  g_signal_connect (G_OBJECT (adj), "value-changed",
+  g_signal_connect (adj, "value-changed",
 		    G_CALLBACK (adjustment_changed),
 		    (gpointer) conf_key);
 
@@ -395,8 +394,10 @@ gnome_prefs_spin_new (GtkWidget *table,
 
   if (box) {
    
+    guint ncols;
+    g_object_get (G_OBJECT (table), "n-columns", &ncols, NULL);
     gtk_table_attach (GTK_TABLE (table), hbox, 
-		      0, GTK_TABLE (table)->ncols, row, row+1,
+		      0, ncols, row, row+1,
 		      (GtkAttachOptions) (GTK_FILL),
 		      (GtkAttachOptions) (GTK_FILL),
 		      0, 0);
@@ -406,7 +407,7 @@ gnome_prefs_spin_new (GtkWidget *table,
   if (gpw && tooltip)
     gtk_widget_set_tooltip_text (spin_button, tooltip);
 
-  g_signal_connect (G_OBJECT (adj), "value-changed",
+  g_signal_connect (adj, "value-changed",
 		    G_CALLBACK (adjustment_changed),
 		    (gpointer) conf_key);
 
@@ -501,13 +502,13 @@ gnome_prefs_range_new (GtkWidget *table,
   }
   
 
-  g_signal_connect (G_OBJECT (adj1), "value-changed",
+  g_signal_connect (adj1, "value-changed",
 		    G_CALLBACK (adjustment_changed),
 		    (gpointer) spin1_conf_key);
   gm_conf_notifier_add (spin1_conf_key, adjustment_changed_nt,
 			(gpointer) adj1);
   
-  g_signal_connect (G_OBJECT (adj2), "value-changed",
+  g_signal_connect (adj2, "value-changed",
 		    G_CALLBACK (adjustment_changed),
 		    (gpointer) spin2_conf_key);
   gm_conf_notifier_add (spin2_conf_key, adjustment_changed_nt,
@@ -593,8 +594,8 @@ gnome_prefs_int_option_menu_new (GtkWidget *table,
   if (gpw && tooltip)
     gtk_widget_set_tooltip_text (option_menu, tooltip);
 
-  g_signal_connect (GTK_COMBO_BOX (option_menu), 
-		    "changed", G_CALLBACK (int_option_menu_changed),
+  g_signal_connect (option_menu, "changed",
+		    G_CALLBACK (int_option_menu_changed),
   		    (gpointer) conf_key);                                   
   gm_conf_notifier_add (conf_key, int_option_menu_changed_nt,
 			(gpointer) option_menu);
@@ -667,7 +668,7 @@ gnome_prefs_string_option_menu_new (GtkWidget *table,
     conf_string = g_strdup (default_value);
   while (options [cpt]) {
 
-    if (conf_string && !strcmp (conf_string, options [cpt]))
+    if (conf_string && !g_strcmp0 (conf_string, options [cpt]))
       history = cpt;
 
     gtk_list_store_append (GTK_LIST_STORE (list_store), &iter);
@@ -681,7 +682,7 @@ gnome_prefs_string_option_menu_new (GtkWidget *table,
 
   if (history == -1) {
 
-    if (conf_string && strcmp (conf_string, "")) {
+    if (conf_string && g_strcmp0 (conf_string, "")) {
 
       gtk_list_store_append (GTK_LIST_STORE (list_store), &iter);
       gtk_list_store_set (GTK_LIST_STORE (list_store), &iter,
@@ -692,7 +693,7 @@ gnome_prefs_string_option_menu_new (GtkWidget *table,
       history = cpt;
     }
     else
-      history = --cpt;
+      history = 0;
   }
 
   gtk_combo_box_set_active (GTK_COMBO_BOX (option_menu), history);
@@ -705,8 +706,8 @@ gnome_prefs_string_option_menu_new (GtkWidget *table,
   if (gpw && tooltip)
     gtk_widget_set_tooltip_text (option_menu, tooltip);
 
-  g_signal_connect (GTK_COMBO_BOX (option_menu), 
-		    "changed", G_CALLBACK (string_option_menu_changed),
+  g_signal_connect (option_menu, "changed",
+		    G_CALLBACK (string_option_menu_changed),
   		    (gpointer) conf_key);                                   
   gm_conf_notifier_add (conf_key, string_option_menu_changed_nt,
 			(gpointer) option_menu);
@@ -729,7 +730,6 @@ gnome_prefs_string_option_menu_update (GtkWidget *option_menu,
   GtkTreeIter iter;
 
   gchar *conf_string = NULL;
-  gchar *options_string = NULL;
   
   int history = -1;
   int cpt = 0;
@@ -748,23 +748,21 @@ gnome_prefs_string_option_menu_update (GtkWidget *option_menu,
   cpt = 0;
   while (options [cpt]) {
 
-    options_string = g_locale_to_utf8 (options [cpt], -1, NULL, NULL, NULL);
-    if (conf_string && !strcmp (options [cpt], conf_string)) 
+    if (conf_string && !g_strcmp0 (options [cpt], conf_string)) 
       history = cpt;
 
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
     gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
                         COLUMN_STRING_RAW, options [cpt],
-                        COLUMN_STRING_TRANSLATED, options_string,
+                        COLUMN_STRING_TRANSLATED, options [cpt],
                         COLUMN_SENSITIVE, TRUE, 
                         -1);
-    g_free (options_string);
     cpt++;
   }
 
   if (history == -1) {
     
-    if (conf_string && strcmp (conf_string, "")) {
+    if (conf_string && g_strcmp0 (conf_string, "")) {
 
       gtk_list_store_append (GTK_LIST_STORE (model), &iter);
       gtk_list_store_set (GTK_LIST_STORE (model), &iter,
@@ -791,14 +789,12 @@ gnome_prefs_string_option_menu_add (GtkWidget *option_menu,
 {
   GtkTreeModel *model = NULL;
   GtkTreeIter iter;
-  gchar *option_string = NULL;
   gboolean found = FALSE;
 
   if (!option)
     return;
 
   model = gtk_combo_box_get_model (GTK_COMBO_BOX (option_menu));
-  option_string = g_locale_to_utf8 (option, -1, NULL, NULL, NULL);
 
   if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter)) {
 
@@ -824,13 +820,12 @@ gnome_prefs_string_option_menu_add (GtkWidget *option_menu,
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
     gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
                         COLUMN_STRING_RAW, option,
-                        COLUMN_STRING_TRANSLATED, option_string, 
+                        COLUMN_STRING_TRANSLATED, option, 
                         COLUMN_SENSITIVE, TRUE,
                         -1);
   }
   if (active == TRUE)
     gtk_combo_box_set_active_iter (GTK_COMBO_BOX (option_menu), &iter);
-  g_free (option_string);
 }
 
 
@@ -979,7 +974,6 @@ gnome_prefs_window_new (const gchar *logo_name)
   gpw->notebook = gtk_notebook_new ();
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (gpw->notebook), FALSE);
   gtk_notebook_set_show_border (GTK_NOTEBOOK (gpw->notebook), FALSE);
-  gtk_notebook_popup_enable (GTK_NOTEBOOK (gpw->notebook));
 
   pixmap =  gtk_image_new_from_file (logo_name);
 
@@ -998,7 +992,7 @@ gnome_prefs_window_new (const gchar *logo_name)
 
 
   /* The sections */
-  dialog_vbox = GTK_DIALOG (window)->vbox;
+  dialog_vbox = gtk_dialog_get_content_area (GTK_DIALOG (window));
   
   hbox = gtk_hbox_new (FALSE, 6);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
