@@ -40,13 +40,12 @@
 #include "config.h"
 
 #include "preferences.h"
-
+#include "default_devices.h"
 #include "accounts.h"
-#include "ekiga.h"
-#include "misc.h"
 #include "callbacks.h"
 
 #include <gmdialog.h>
+#include "gmwindow.h"
 #include <gmpreferences.h>
 #include <gmconf.h>
 #include "codecsbox.h"
@@ -69,8 +68,9 @@ typedef struct _GmPreferencesWindow
   GtkWidget *audio_recorder;
   GtkWidget *video_device;
   GtkWidget *iface;
+  GtkWidget *fsbutton;
   Ekiga::ServiceCore *core;
-  std::vector<sigc::connection> connections;
+  std::vector<boost::signals::connection> connections;
 } GmPreferencesWindow;
 
 #define GM_PREFERENCES_WINDOW(x) (GmPreferencesWindow *) (x)
@@ -288,13 +288,13 @@ static void sound_events_list_changed_nt (gpointer id,
 static void audioev_filename_browse_play_cb (GtkWidget *playbutton,
                                              gpointer data);
 
-void 
+int 
 gm_prefs_window_get_audiooutput_devices_list (Ekiga::ServiceCore *core,
                                         std::vector<std::string> & device_list);
 
-void 
+int 
 gm_prefs_window_get_audioinput_devices_list (Ekiga::ServiceCore *core,
-                                        std::vector<std::string> & device_list);
+                                             std::vector<std::string> & device_list);
 
 gchar**
 gm_prefs_window_convert_string_list (const std::vector<std::string> & list);
@@ -407,20 +407,29 @@ static GtkWidget *
 gm_pw_add_update_button (G_GNUC_UNUSED GtkWidget *prefs_window,
                          GtkWidget *box,
                          const char *stock_id,
-                         const char *label,
+                         const char *label_,
                          GCallback func,
                          G_GNUC_UNUSED gchar *tooltip,
                          gfloat valign,
                          gpointer data)
 {
-  GtkWidget *alignment = NULL;
-  GtkWidget *image = NULL;
-  GtkWidget *button = NULL;
+  GtkWidget* alignment = NULL;
+  GtkWidget* image = NULL;
+  GtkWidget* button = NULL;
+  GtkWidget* hbox = NULL;
+  GtkWidget* label = NULL;
 
 
   /* Update Button */
   image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
-  button = gnomemeeting_button_new (label, image);
+  button = gtk_button_new ();
+  label = gtk_label_new_with_mnemonic (label_);
+  hbox = gtk_hbox_new (FALSE, 0);
+
+  gtk_box_pack_start(GTK_BOX (hbox), image, TRUE, TRUE, 0);  
+  gtk_box_pack_start(GTK_BOX (hbox), label, TRUE, TRUE, 0);
+
+  gtk_container_add (GTK_CONTAINER (button), hbox);
 
   alignment = gtk_alignment_new (1, valign, 0, 0);
   gtk_container_add (GTK_CONTAINER (alignment), button);
@@ -428,7 +437,7 @@ gm_pw_add_update_button (G_GNUC_UNUSED GtkWidget *prefs_window,
 
   gtk_box_pack_start (GTK_BOX (box), alignment, TRUE, TRUE, 0);
 
-  g_signal_connect (G_OBJECT (button), "clicked",
+  g_signal_connect (button, "clicked",
                     G_CALLBACK (func), 
                     (gpointer) data);
 
@@ -449,7 +458,7 @@ gm_pw_init_general_page (GtkWidget *prefs_window,
   pw = gm_pw_get_pw (prefs_window);
 
   /* Personal Information */
-  subsection = 
+  subsection =
     gnome_prefs_subsection_new (prefs_window, container,
                                 _("Personal Information"), 2, 2);
 
@@ -480,16 +489,16 @@ gm_pw_init_interface_page (GtkWidget *prefs_window,
 
   /* Video Display */
   subsection =
-    gnome_prefs_subsection_new (prefs_window, container, 
+    gnome_prefs_subsection_new (prefs_window, container,
                                 _("Video Display"), 1, 2);
 
   gnome_prefs_toggle_new (subsection, _("Place windows displaying video _above other windows"), VIDEO_DISPLAY_KEY "stay_on_top", _("Place windows displaying video above other windows during calls"), 0);
 
   /* Network Settings */
-  subsection = gnome_prefs_subsection_new (prefs_window, container, 
+  subsection = gnome_prefs_subsection_new (prefs_window, container,
                                            _("Network Settings"), 1, 2);
 
-  gnome_prefs_toggle_new (subsection, _("Disable network _detection"), NAT_KEY "disable_stun", _("Disable the automatic network setup resulting from the STUN test"), 0);
+  gnome_prefs_toggle_new (subsection, _("Enable network _detection"), NAT_KEY "enable_stun", _("Enable the automatic network setup resulting from the STUN test"), 0);
 
 }
 
@@ -513,7 +522,8 @@ gm_pw_init_call_options_page (GtkWidget *prefs_window,
                                            _("Call Options"), 2, 3);
 
   /* Add all the fields */
-  gnome_prefs_spin_new (subsection, _("Timeout to reject or forward unanswered incoming calls (in seconds):"), CALL_OPTIONS_KEY "no_answer_timeout", _("Automatically reject or forward incoming calls if no answer is given after the specified amount of time (in seconds)"), 10.0, 299.0, 1.0, 1, NULL, true);
+  gnome_prefs_spin_new (subsection, _("Timeout to reject or forward unanswered incoming calls (in seconds):"), CALL_OPTIONS_KEY "no_answer_timeout", _("Automatically reject or forward incoming calls if no answer is given after the specified amount of time (in seconds)"), 10.0, 299.0, 1.0, 0, NULL, true);
+  gnome_prefs_toggle_new (subsection, _("_Automatically answer incoming calls"), CALL_OPTIONS_KEY "auto_answer", _("If enabled, automatically answer incoming calls"), 1);
 }
 
 
@@ -524,7 +534,6 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
   GmPreferencesWindow *pw= NULL;
 
   GtkWidget *button = NULL;
-  GtkWidget *fsbutton = NULL;
   GtkWidget *hbox = NULL;
   GtkWidget *frame = NULL;
   GtkWidget *vbox = NULL;
@@ -590,7 +599,7 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
                                                      NULL);
   gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 25);
   gtk_tree_view_append_column (GTK_TREE_VIEW (pw->sound_events_list), column);
-  g_signal_connect (G_OBJECT (renderer), "toggled",
+  g_signal_connect (renderer, "toggled",
                     G_CALLBACK (sound_event_toggled_cb), 
                     GTK_TREE_MODEL (list_store));
 
@@ -606,10 +615,10 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
   hbox = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 2);
 
-  fsbutton =
+  pw->fsbutton =
     gtk_file_chooser_button_new (_("Choose a sound"),
                                  GTK_FILE_CHOOSER_ACTION_OPEN);
-  gtk_box_pack_start (GTK_BOX (hbox), fsbutton, TRUE, TRUE, 2);
+  gtk_box_pack_start (GTK_BOX (hbox), pw->fsbutton, TRUE, TRUE, 2);
 
   filefilter = gtk_file_filter_new ();
   gtk_file_filter_set_name (filefilter, _("Wavefiles"));
@@ -618,32 +627,32 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
 #else
   gtk_file_filter_add_mime_type (filefilter, "audio/x-wav");
 #endif
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (fsbutton), filefilter);
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (pw->fsbutton), filefilter);
 
   selector_hbox = gtk_hbox_new (FALSE, 0);
   selector_playbutton = gtk_button_new_with_label (_("Play"));
   gtk_box_pack_end (GTK_BOX (selector_hbox),
                     selector_playbutton, FALSE, FALSE, 0);
   gtk_widget_show (selector_playbutton);
-  gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (fsbutton),
+  gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (pw->fsbutton),
                                      selector_hbox);
 
-  g_signal_connect (G_OBJECT (selector_playbutton), "clicked",
+  g_signal_connect (selector_playbutton, "clicked",
                     G_CALLBACK (audioev_filename_browse_play_cb),
-                    (gpointer) fsbutton);
+                    (gpointer) prefs_window);
 
-  g_signal_connect (G_OBJECT (fsbutton), "selection-changed",
+  g_signal_connect (pw->fsbutton, "selection-changed",
                     G_CALLBACK (audioev_filename_browse_cb),
                     (gpointer) prefs_window);
 
-  g_signal_connect (G_OBJECT (selection), "changed",
+  g_signal_connect (selection, "changed",
                     G_CALLBACK (sound_event_clicked_cb),
-                    (gpointer) fsbutton);
+                    (gpointer) pw->fsbutton);
 
   button = gtk_button_new_with_label (_("Play"));
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 2);
 
-  g_signal_connect (G_OBJECT (button), "clicked",
+  g_signal_connect (button, "clicked",
                     G_CALLBACK (sound_event_play_cb),
                     (gpointer) prefs_window);
 
@@ -765,16 +774,16 @@ gm_pw_init_audio_devices_page (GtkWidget *prefs_window,
   gm_prefs_window_get_audiooutput_devices_list (pw->core, device_list);
   array = gm_prefs_window_convert_string_list(device_list);
   pw->sound_events_output = 
-    gnome_prefs_string_option_menu_new (subsection, _("Ringing Device"), (const gchar **)array, SOUND_EVENTS_KEY "output_device", _("Select the ringing audio device to use"), 0, get_default_audio_device_name ());
+    gnome_prefs_string_option_menu_new (subsection, _("Ringing Device"), (const gchar **)array, SOUND_EVENTS_KEY "output_device", _("Select the ringing audio device to use"), 0, DEFAULT_AUDIO_DEVICE_NAME);
   pw->audio_player =
-    gnome_prefs_string_option_menu_new (subsection, _("Output device:"), (const gchar **)array, AUDIO_DEVICES_KEY "output_device", _("Select the audio output device to use"), 1, get_default_audio_device_name ());
+    gnome_prefs_string_option_menu_new (subsection, _("Output device:"), (const gchar **)array, AUDIO_DEVICES_KEY "output_device", _("Select the audio output device to use"), 1, DEFAULT_AUDIO_DEVICE_NAME);
   g_free (array);
 
   /* The recorder */
   gm_prefs_window_get_audioinput_devices_list (pw->core, device_list);
   array = gm_prefs_window_convert_string_list(device_list);
   pw->audio_recorder =
-    gnome_prefs_string_option_menu_new (subsection, _("Input device:"), (const gchar **)array, AUDIO_DEVICES_KEY "input_device", _("Select the audio input device to use"), 2, get_default_audio_device_name ());
+    gnome_prefs_string_option_menu_new (subsection, _("Input device:"), (const gchar **)array, AUDIO_DEVICES_KEY "input_device", _("Select the audio input device to use"), 2, DEFAULT_AUDIO_DEVICE_NAME);
   g_free (array);
 
 
@@ -783,12 +792,11 @@ gm_pw_init_audio_devices_page (GtkWidget *prefs_window,
 }
 
 
-void 
+int 
 gm_prefs_window_get_videoinput_devices_list (Ekiga::ServiceCore *core,
-                                        std::vector<std::string> & device_list)
+                                             std::vector<std::string> & device_list)
 {
-  gmref_ptr<Ekiga::VideoInputCore> videoinput_core
-    = core->get ("videoinput-core");
+  boost::shared_ptr<Ekiga::VideoInputCore> videoinput_core = core->get<Ekiga::VideoInputCore> ("videoinput-core");
   std::vector <Ekiga::VideoInputDevice> devices;
 
   device_list.clear();
@@ -796,22 +804,21 @@ gm_prefs_window_get_videoinput_devices_list (Ekiga::ServiceCore *core,
 
   for (std::vector<Ekiga::VideoInputDevice>::iterator iter = devices.begin ();
        iter != devices.end ();
-       iter++) {
-
+       iter++) 
     device_list.push_back(iter->GetString());
-  }
 
-  if (device_list.size() == 0) {
+  if (device_list.size() == 0) 
     device_list.push_back(_("No device found"));
-  }
+
+  return device_list.size ();
 }
 
-void 
+
+int 
 gm_prefs_window_get_audiooutput_devices_list (Ekiga::ServiceCore *core,
-                                        std::vector<std::string> & device_list)
+                                              std::vector<std::string> & device_list)
 {
-  gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
-    = core->get ("audiooutput-core");
+  boost::shared_ptr<Ekiga::AudioOutputCore> audiooutput_core = core->get<Ekiga::AudioOutputCore> ("audiooutput-core");
   std::vector <Ekiga::AudioOutputDevice> devices;
 
   std::string device_string;
@@ -821,23 +828,21 @@ gm_prefs_window_get_audiooutput_devices_list (Ekiga::ServiceCore *core,
 
   for (std::vector<Ekiga::AudioOutputDevice>::iterator iter = devices.begin ();
        iter != devices.end ();
-       iter++) {
-
+       iter++)
     device_list.push_back(iter->GetString());
-  }
 
-  if (device_list.size() == 0) {
+  if (device_list.size() == 0)
     device_list.push_back(_("No device found"));
-  }
+
+  return device_list.size ();
 }
 
 
-void 
+int
 gm_prefs_window_get_audioinput_devices_list (Ekiga::ServiceCore *core,
-                                        std::vector<std::string> & device_list)
+                                             std::vector<std::string> & device_list)
 {
-  gmref_ptr<Ekiga::AudioInputCore> audioinput_core
-    = core->get ("audioinput-core");
+  boost::shared_ptr<Ekiga::AudioInputCore> audioinput_core = core->get<Ekiga::AudioInputCore> ("audioinput-core");
   std::vector <Ekiga::AudioInputDevice> devices;
 
   device_list.clear();
@@ -845,14 +850,13 @@ gm_prefs_window_get_audioinput_devices_list (Ekiga::ServiceCore *core,
 
   for (std::vector<Ekiga::AudioInputDevice>::iterator iter = devices.begin ();
        iter != devices.end ();
-       iter++) {
-
+       iter++)
     device_list.push_back(iter->GetString());
-  }
 
-  if (device_list.size() == 0) {
+  if (device_list.size() == 0)
     device_list.push_back(_("No device found"));
-  }
+
+  return device_list.size ();
 }
 
 
@@ -921,7 +925,6 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
                                            _("Video Devices"), 5, 3);
 
   /* The video device */
-
   gm_prefs_window_get_videoinput_devices_list (pw->core, device_list);
   array = gm_prefs_window_convert_string_list(device_list);
   pw->video_device =
@@ -1082,14 +1085,13 @@ audioev_filename_browse_cb (GtkWidget *b,
 static void
 sound_events_list_changed_nt (G_GNUC_UNUSED gpointer id,
 			      GmConfEntry *entry,
-			      G_GNUC_UNUSED gpointer data)
+			      gpointer data)
 {
-  GtkWidget *prefs_window;
+  GtkWidget *prefs_window = (GtkWidget*)data;
 
   if (gm_conf_entry_get_type (entry) == GM_CONF_STRING
       || gm_conf_entry_get_type (entry) == GM_CONF_BOOL) {
-   
-    prefs_window = GnomeMeeting::Process ()->GetPrefsWindow (false);
+
     if (prefs_window) {
       gm_prefs_window_sound_events_list_build (prefs_window);
     }
@@ -1159,9 +1161,7 @@ sound_event_play_cb (G_GNUC_UNUSED GtkWidget *widget,
 
     gtk_tree_model_get (GTK_TREE_MODEL (model), &selected_iter, 4, &sound_event, -1);
 
-    //FIXME
-    Ekiga::ServiceCore *core = GnomeMeeting::Process ()->GetServiceCore (); 
-    gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core = core->get ("audiooutput-core");
+    boost::shared_ptr<Ekiga::AudioOutputCore> audiooutput_core = pw->core->get<Ekiga::AudioOutputCore> ("audiooutput-core");
 
     if (sound_event) { 
       audiooutput_core->play_event(sound_event);
@@ -1204,14 +1204,15 @@ static void
 audioev_filename_browse_play_cb (GtkWidget* /* playbutton */,
 				 gpointer data)
 {
+  GmPreferencesWindow* pw = NULL;
+
   g_return_if_fail (data != NULL);
 
-  //FIXME
-  Ekiga::ServiceCore *core = GnomeMeeting::Process ()->GetServiceCore (); 
-  gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
-    = core->get ("audiooutput-core");
+  pw = gm_pw_get_pw (GTK_WIDGET (data));
 
-  gchar* file_name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (data));
+  boost::shared_ptr<Ekiga::AudioOutputCore> audiooutput_core = pw->core->get<Ekiga::AudioOutputCore> ("audiooutput-core");
+
+  gchar* file_name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (pw->fsbutton));
   std::string file_name_string = file_name;
   audiooutput_core->play_file(file_name_string);
 
@@ -1287,11 +1288,11 @@ gm_prefs_window_update_devices_list (GtkWidget *prefs_window)
   gnome_prefs_string_option_menu_update (pw->audio_player,
  					 (const gchar **)array,
  					 AUDIO_DEVICES_KEY "output_device",
- 					 get_default_audio_device_name ());
+ 					 DEFAULT_AUDIO_DEVICE_NAME);
   gnome_prefs_string_option_menu_update (pw->sound_events_output,
                                          (const gchar **)array,
                                          SOUND_EVENTS_KEY "output_device",
-                                         get_default_audio_device_name ());
+                                         DEFAULT_AUDIO_DEVICE_NAME);
   g_free (array);
 
   /* The recorder */
@@ -1300,7 +1301,7 @@ gm_prefs_window_update_devices_list (GtkWidget *prefs_window)
   gnome_prefs_string_option_menu_update (pw->audio_recorder,
  					 (const gchar **)array,
  					 AUDIO_DEVICES_KEY "input_device",
- 					 get_default_audio_device_name ());
+ 					 DEFAULT_AUDIO_DEVICE_NAME);
   g_free (array);
 
 
@@ -1324,6 +1325,7 @@ gm_prefs_window_new (Ekiga::ServiceCore *core)
   GtkWidget *window = NULL;
   GtkWidget *container = NULL;
   gchar     *filename = NULL;
+  std::vector <std::string> device_list;
 
   filename = g_build_filename (DATA_DIR, "pixmaps", PACKAGE_NAME, PACKAGE_NAME "-logo.png", NULL);
   window = gnome_prefs_window_new (filename);
@@ -1378,90 +1380,89 @@ gm_prefs_window_new (Ekiga::ServiceCore *core)
   gm_pw_init_h323_page (window, container);          
   gtk_widget_show_all (GTK_WIDGET (container));
 
-  gnome_prefs_window_section_new (window, _("Audio"));
-  container = gnome_prefs_window_subsection_new (window, _("Devices"));
-  gm_pw_init_audio_devices_page (window, container);
-  gtk_widget_show_all (GTK_WIDGET (container));
 
+  /* The player */
+  gnome_prefs_window_section_new (window, _("Audio"));
+  if (gm_prefs_window_get_audiooutput_devices_list (core, device_list) > 1 
+      || gm_prefs_window_get_audioinput_devices_list (core, device_list) > 1) {
+    container = gnome_prefs_window_subsection_new (window, _("Devices"));
+    gm_pw_init_audio_devices_page (window, container);
+    gtk_widget_show_all (GTK_WIDGET (container));
+  }
   container = gnome_prefs_window_subsection_new (window, _("Codecs"));
   gm_pw_init_audio_codecs_page (window, container);
   gtk_widget_show_all (GTK_WIDGET (container));
 
 
   gnome_prefs_window_section_new (window, _("Video"));
-  container = gnome_prefs_window_subsection_new (window, _("Devices"));
-  gm_pw_init_video_devices_page (window, container);
-  gtk_widget_show_all (GTK_WIDGET (container));
-
+  if (gm_prefs_window_get_videoinput_devices_list (core, device_list) > 1) {
+    container = gnome_prefs_window_subsection_new (window, _("Devices"));
+    gm_pw_init_video_devices_page (window, container);
+    gtk_widget_show_all (GTK_WIDGET (container));
+  }
   container = gnome_prefs_window_subsection_new (window, _("Codecs"));
   gm_pw_init_video_codecs_page (window, container);
   gtk_widget_show_all (GTK_WIDGET (container));
 
 
   /* That's an usual GtkWindow, connect it to the signals */
-  g_signal_connect_swapped (GTK_OBJECT (window), 
-			    "response", 
-			    G_CALLBACK (gnomemeeting_window_hide),
+  g_signal_connect_swapped (window, "response",
+			    G_CALLBACK (gm_window_hide),
 			    (gpointer) window);
 
-  g_signal_connect (GTK_OBJECT (window), 
-		    "delete-event", 
-		    G_CALLBACK (delete_window_cb), NULL);
+  gm_window_hide_on_delete (window);
 
-  sigc::connection conn;
-  gmref_ptr<Ekiga::VideoInputCore> videoinput_core
-    = core->get ("videoinput-core");
-  gmref_ptr<Ekiga::AudioInputCore> audioinput_core
-    = core->get ("audioinput-core");
-  gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
-    = core->get ("audiooutput-core");
+  boost::signals::connection conn;
+  boost::shared_ptr<Ekiga::VideoInputCore> videoinput_core = core->get<Ekiga::VideoInputCore> ("videoinput-core");
+  boost::shared_ptr<Ekiga::AudioInputCore> audioinput_core = core->get<Ekiga::AudioInputCore> ("audioinput-core");
+  boost::shared_ptr<Ekiga::AudioOutputCore> audiooutput_core = core->get<Ekiga::AudioOutputCore> ("audiooutput-core");
 
-  conn = videoinput_core->device_added.connect (sigc::bind (sigc::ptr_fun (on_videoinput_device_added_cb), window));
+  conn = videoinput_core->device_added.connect (boost::bind (&on_videoinput_device_added_cb, _1, _2, window));
   pw->connections.push_back (conn);
-  conn = videoinput_core->device_removed.connect (sigc::bind (sigc::ptr_fun (on_videoinput_device_removed_cb), window));
+  conn = videoinput_core->device_removed.connect (boost::bind (&on_videoinput_device_removed_cb, _1, _2, window));
   pw->connections.push_back (conn);
 
-  conn = audioinput_core->device_added.connect (sigc::bind (sigc::ptr_fun (on_audioinput_device_added_cb), window));
+  conn = audioinput_core->device_added.connect (boost::bind (&on_audioinput_device_added_cb, _1, _2, window));
   pw->connections.push_back (conn);
-  conn = audioinput_core->device_removed.connect (sigc::bind (sigc::ptr_fun (on_audioinput_device_removed_cb), window));
+  conn = audioinput_core->device_removed.connect (boost::bind (&on_audioinput_device_removed_cb, _1, _2, window));
   pw->connections.push_back (conn);
 
-  conn = audiooutput_core->device_added.connect (sigc::bind (sigc::ptr_fun (on_audiooutput_device_added_cb), window));
+  conn = audiooutput_core->device_added.connect (boost::bind (&on_audiooutput_device_added_cb, _1, _2, window));
   pw->connections.push_back(conn);
-  conn = audiooutput_core->device_removed.connect (sigc::bind (sigc::ptr_fun (on_audiooutput_device_removed_cb), window));
+  conn = audiooutput_core->device_removed.connect (boost::bind (&on_audiooutput_device_removed_cb, _1, _2, window));
   pw->connections.push_back (conn);
 
 
   /* Connect notifiers for SOUND_EVENTS_KEY keys */
   gm_conf_notifier_add (SOUND_EVENTS_KEY "enable_incoming_call_sound", 
-			sound_events_list_changed_nt, NULL);
+			sound_events_list_changed_nt, window);
   
   gm_conf_notifier_add (SOUND_EVENTS_KEY "incoming_call_sound",
-			sound_events_list_changed_nt, NULL);
+			sound_events_list_changed_nt, window);
 
   gm_conf_notifier_add (SOUND_EVENTS_KEY "enable_ring_tone_sound", 
-			sound_events_list_changed_nt, NULL);
+			sound_events_list_changed_nt, window);
   
   gm_conf_notifier_add (SOUND_EVENTS_KEY "ring_tone_sound", 
-			sound_events_list_changed_nt, NULL);
+			sound_events_list_changed_nt, window);
   
   gm_conf_notifier_add (SOUND_EVENTS_KEY "enable_busy_tone_sound", 
-			sound_events_list_changed_nt, NULL);
+			sound_events_list_changed_nt, window);
   
   gm_conf_notifier_add (SOUND_EVENTS_KEY "busy_tone_sound",
-			sound_events_list_changed_nt, NULL);
+			sound_events_list_changed_nt, window);
   
   gm_conf_notifier_add (SOUND_EVENTS_KEY "enable_new_voicemail_sound", 
-			sound_events_list_changed_nt, NULL);
+			sound_events_list_changed_nt, window);
   
   gm_conf_notifier_add (SOUND_EVENTS_KEY "new_voicemail_sound",
-			sound_events_list_changed_nt, NULL);
+			sound_events_list_changed_nt, window);
 
   gm_conf_notifier_add (SOUND_EVENTS_KEY "enable_new_message_sound",
-			sound_events_list_changed_nt, NULL);
+			sound_events_list_changed_nt, window);
 
   gm_conf_notifier_add (SOUND_EVENTS_KEY "new_message_sound",
-			sound_events_list_changed_nt, NULL);
+			sound_events_list_changed_nt, window);
 
   return window;
 }
