@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2008 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,32 +36,22 @@
  */
 
 
-/*
- * The StatusMenu can be seen as an extended preferences window. 
- * It can thus directly react to GMConf key changes and write in the GMConf 
- * database.
- *
- * It does not need to listen to sigc++ signals to react to key changes.
- *
- */
 
-#include "config.h"
 #include "statusmenu.h"
 
+#include "common.h"
 #include "personal-details.h"
 
 #include "gmconf.h"
 #include "gmstockicons.h"
 
-#include "common.h"
-
+#include <glib/gi18n.h>
+#include <vector>
 
 struct _StatusMenuPrivate
 {
-  _StatusMenuPrivate (Ekiga::PersonalDetails & d) : personal_details (d) {};
-
-  Ekiga::PersonalDetails & personal_details;
-  std::vector<sigc::connection> connections;
+  boost::shared_ptr<Ekiga::PersonalDetails> personal_details;
+  std::vector<boost::signals::connection> connections;
 
   GtkListStore *list_store; // List store storing the menu
   GtkWindow    *parent;     // Parent window
@@ -278,27 +268,27 @@ status_menu_option_changed (GtkComboBox *box,
     switch (i)
       {
       case TYPE_ONLINE:
-        self->priv->personal_details.set_presence_info ("online", "");
+        self->priv->personal_details->set_presence_info ("online", "");
         break;
 
       case TYPE_AWAY:
-        self->priv->personal_details.set_presence_info ("away", "");
+        self->priv->personal_details->set_presence_info ("away", "");
         break;
 
       case TYPE_DND:
-        self->priv->personal_details.set_presence_info ("dnd", "");
+        self->priv->personal_details->set_presence_info ("dnd", "");
         break;
 
       case TYPE_CUSTOM_ONLINE:
-        self->priv->personal_details.set_presence_info ("online", status);
+        self->priv->personal_details->set_presence_info ("online", status);
         break;
 
       case TYPE_CUSTOM_AWAY:
-        self->priv->personal_details.set_presence_info ("away", status);
+        self->priv->personal_details->set_presence_info ("away", status);
         break;
 
       case TYPE_CUSTOM_DND:
-        self->priv->personal_details.set_presence_info ("dnd", status);
+        self->priv->personal_details->set_presence_info ("dnd", status);
         break;
 
       case TYPE_CUSTOM_ONLINE_NEW:
@@ -354,7 +344,7 @@ status_menu_custom_messages_changed (gpointer /*id*/,
 static void
 on_details_updated (StatusMenu *self)
 {
-  status_menu_set_option (self, self->priv->personal_details.get_presence (), self->priv->personal_details.get_status ());
+  status_menu_set_option (self, self->priv->personal_details->get_presence (), self->priv->personal_details->get_status ());
 }
 
 
@@ -444,7 +434,7 @@ status_menu_populate (StatusMenu *self,
     g_object_unref (icon);
   }
 
-  status_menu_set_option (self, self->priv->personal_details.get_presence (), self->priv->personal_details.get_status ());
+  status_menu_set_option (self, self->priv->personal_details->get_presence (), self->priv->personal_details->get_status ());
 }
 
 
@@ -460,7 +450,8 @@ status_menu_set_option (StatusMenu *self,
   int i = 0;
   int cpt = 0;
 
-  g_return_if_fail (!presence.empty ());
+  if (presence.empty ())
+    return;
 
   valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (self->priv->list_store), &iter);
   while (valid) {
@@ -648,7 +639,7 @@ status_menu_clear_status_message_dialog_run (StatusMenu *self)
 
   if (!found) {
     // Reset current config
-    self->priv->personal_details.set_presence_info ("online", "");
+    self->priv->personal_details->set_presence_info ("online", "");
   }
 
   gtk_widget_destroy (dialog);
@@ -713,20 +704,20 @@ status_menu_new_status_message_dialog_run (StatusMenu *self,
   case GTK_RESPONSE_ACCEPT:
     message = gtk_entry_get_text (GTK_ENTRY (entry));
     clist = gm_conf_get_string_list (status_types_keys[option - NUM_STATUS_TYPES - 1]);
-    if (strcmp (message, "")) { 
+    if (message && strcmp (message, "")) { 
       clist = g_slist_append (clist, g_strdup (message));
       gm_conf_set_string_list (status_types_keys[option - NUM_STATUS_TYPES - 1], clist);
-      self->priv->personal_details.set_presence_info (status_types_names[option - NUM_STATUS_TYPES - 1], message);
+      self->priv->personal_details->set_presence_info (status_types_names[option - NUM_STATUS_TYPES - 1], message);
     }
     else {
-      status_menu_set_option (self, presence, status);
+      status_menu_set_option (self, presence ? presence : "", status ? status : "");
     }
     g_slist_foreach (clist, (GFunc) g_free, NULL);
     g_slist_free (clist);
     break;
 
   default:
-    status_menu_set_option (self, presence, status);
+    status_menu_set_option (self, presence ? presence : "", status ? status : "");
     break;
   }
 
@@ -811,16 +802,15 @@ GtkWidget *
 status_menu_new (Ekiga::ServiceCore & core)
 {
   StatusMenu *self = NULL;
-  Ekiga::PersonalDetails *details = NULL;
 
-  sigc::connection conn;
+  boost::signals::connection conn;
   GtkCellRenderer *renderer = NULL;
   GSList *custom_status_array [NUM_STATUS_TYPES];
 
   self = (StatusMenu *) g_object_new (STATUS_MENU_TYPE, NULL);
-  details = dynamic_cast<Ekiga::PersonalDetails*> (core.get ("personal-details"));
-  self->priv = new StatusMenuPrivate (*details);
+  self->priv = new StatusMenuPrivate ();
 
+  self->priv->personal_details = core.get<Ekiga::PersonalDetails> ("personal-details");
   self->priv->parent = NULL;
   self->priv->list_store = gtk_list_store_new (NUM_COLUMNS,
                                                GDK_TYPE_PIXBUF,
@@ -860,9 +850,9 @@ status_menu_new (Ekiga::ServiceCore & core)
                                         (GtkTreeViewRowSeparatorFunc) status_menu_row_is_separator,
                                         NULL, NULL);
   gtk_container_set_border_width (GTK_CONTAINER (self), 0);
-  status_menu_set_option (self, self->priv->personal_details.get_presence (), self->priv->personal_details.get_status ());
+  status_menu_set_option (self, self->priv->personal_details->get_presence (), self->priv->personal_details->get_status ());
 
-  g_signal_connect (G_OBJECT (self), "changed",
+  g_signal_connect (self, "changed",
                     G_CALLBACK (status_menu_option_changed), self);
 
   gm_conf_notifier_add (PERSONAL_DATA_KEY "online_custom_status", 
@@ -872,7 +862,7 @@ status_menu_new (Ekiga::ServiceCore & core)
   gm_conf_notifier_add (PERSONAL_DATA_KEY "dnd_custom_status", 
                         status_menu_custom_messages_changed, self);
 
-  conn = self->priv->personal_details.updated.connect (sigc::bind (sigc::ptr_fun (on_details_updated), self)); 
+  conn = self->priv->personal_details->updated.connect (boost::bind (&on_details_updated, self)); 
   self->priv->connections.push_back (conn);
 
   return GTK_WIDGET (self);
